@@ -1,6 +1,7 @@
 #!/usr/bin/env python
 import unittest
 
+import gobject
 import gtk
 
 from kiwi.ui.objectlist import ObjectList, Column
@@ -42,6 +43,14 @@ class ColumnTests(unittest.TestCase):
 
         self.assertEqual(1, len(mylist.get_columns()))
 
+    def testAttribute(self):
+        column = Column('foo')
+        self.assertEquals(column.attribute, "foo")
+
+    def testGObjectNew(self):
+        column = gobject.new(Column, attribute='foo')
+        self.assertEquals(column.attribute, "foo")
+
 class DataTests(unittest.TestCase):
     """In all this tests we use the same configuration for a list"""
     def setUp(self):
@@ -229,6 +238,11 @@ class ConstructorTest(unittest.TestCase):
         columns = klist.get_columns()
         self.assertEqual(len(columns), 1)
 
+    def testGObjectNew(self):
+        olist = gobject.new(ObjectList)
+        self.assertNotEqual(olist.get_vscrollbar(), None)
+        self.assertNotEqual(olist.get_hscrollbar(), None)
+
 class MethodTest(unittest.TestCase):
     def setUp(self):
         self.klist = ObjectList([Column('name', sorted=True)],
@@ -328,6 +342,22 @@ class MethodTest(unittest.TestCase):
         self.assertEqual(self.klist.get_previous(item3), item2)
         self.assertRaises(ValueError, self.klist.get_previous, None)
 
+    def testInsert(self):
+        self.klist = ObjectList([Column('name')])
+        self.assertEqual(list(self.klist), [])
+
+        self.klist.insert(0, Settable(name='one'))
+        self.assertEqual(self.klist[0].name, 'one')
+
+        self.klist.insert(0, Settable(name='two'))
+        self.assertEqual(self.klist[0].name, 'two')
+        self.assertEqual(self.klist[1].name, 'one')
+
+        self.klist.insert(1, Settable(name='three'))
+        self.assertEqual(self.klist[0].name, 'two')
+        self.assertEqual(self.klist[1].name, 'three')
+        self.assertEqual(self.klist[2].name, 'one')
+
 class BooleanDataTests(unittest.TestCase):
     def setUp(self):
         self.list = ObjectList([Column('value', data_type=bool, radio=True,
@@ -355,5 +385,22 @@ class BooleanDataTests(unittest.TestCase):
         self.assertEqual(self.list[0].value, True)
         self.assertEqual(self.list[1].value, False)
 
+
+class RadioColumnTests(unittest.TestCase):
+
+    def testRadioWithoutTrue(self):
+        olist = ObjectList(
+            [Column('foo', radio=True, data_type=bool, editable=True)])
+        column = olist.get_treeview().get_column(0)
+        renderer = column.get_cell_renderers()[0]
+
+        items = [Settable(foo=False) for i in range(5)]
+        olist.add_list(items)
+
+        self.assertEqual(items[0].foo, False)
+        renderer.emit('toggled', 0)
+        self.assertEqual(items[0].foo, True)
+
+
 if __name__ == '__main__':
     unittest.main()
